@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.2.30  Copyright by Tobi Oetiker, 1997-2009
+ * RRDtool 1.3.1  Copyright by Tobi Oetiker, 1997-2008
  *****************************************************************************
  * rrd_last.c
  *****************************************************************************
@@ -8,33 +8,32 @@
 
 #include "rrd_tool.h"
 
-time_t
-rrd_last(int argc, char **argv)
+time_t rrd_last(
+    int argc,
+    char **argv)
 {
-    if(argc < 2){
+    if (argc < 2) {
         rrd_set_error("please specify an rrd");
-        return(-1);
+        return (-1);
     }
 
-    return( rrd_last_r(argv[1]) );
+    return (rrd_last_r(argv[1]));
 }
- 
 
-time_t
-rrd_last_r(const char *filename)
+
+time_t rrd_last_r(
+    const char *filename)
 {
-    FILE	*in_file;
-    time_t       lastup;
+    time_t    lastup = -1;
+    rrd_file_t *rrd_file;
 
-    rrd_t	 rrd;
+    rrd_t     rrd;
 
-    if(rrd_open(filename, &in_file, &rrd, RRD_READONLY)==-1){
-        return(-1);
+    rrd_file = rrd_open(filename, &rrd, RRD_READONLY);
+    if (rrd_file != NULL) {
+        lastup = rrd.live_head->last_up;
+        rrd_close(rrd_file);
     }
-    lastup = rrd.live_head->last_up;
     rrd_free(&rrd);
-    fclose(in_file);
-    return(lastup);
+    return (lastup);
 }
-
-
