@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.2.30  Copyright by Tobi Oetiker, 1997-2009
+ * RRDtool 1.3.1  Copyright by Tobi Oetiker, 1997-2008
  *****************************************************************************
  * rrd_version Return
  *****************************************************************************
@@ -8,16 +8,14 @@
 
 #include "rrd_tool.h"
 
-double
-rrd_version(void)
+double rrd_version(
+    void)
 {
-  return NUMVERS;
+    return NUMVERS;
 }
 
-char *
-rrd_strversion(void)
+char     *rrd_strversion(
+    void)
 {
-  return PACKAGE_VERSION;
+    return PACKAGE_VERSION;
 }
-
-
