@@ -1,5 +1,5 @@
 /****************************************************************************
- * RRDtool 1.2.30  Copyright by Tobi Oetiker, 1997-2009
+ * RRDtool 1.3.1  Copyright by Tobi Oetiker, 1997-2008
  ****************************************************************************
  * rrd_xport.c  export RRD data 
  ****************************************************************************/
@@ -56,8 +56,7 @@ int rrd_xport(
 
     image_desc_t im;
     time_t    start_tmp = 0, end_tmp = 0;
-    struct rrd_time_value start_tv;
-    struct rrd_time_value end_tv;
+    rrd_time_value_t start_tv, end_tv;
     char     *parsetime_error = NULL;
     struct option long_options[] = {
         {"start", required_argument, 0, 's'},
@@ -73,8 +72,8 @@ int rrd_xport(
 
     rrd_graph_init(&im);
 
-    parsetime("end-24h", &start_tv);
-    parsetime("now", &end_tv);
+    rrd_parsetime("end-24h", &start_tv);
+    rrd_parsetime("now", &end_tv);
 
     while (1) {
         int       option_index = 0;
@@ -92,13 +91,13 @@ int rrd_xport(
         case 262:
             break;
         case 's':
-            if ((parsetime_error = parsetime(optarg, &start_tv))) {
+            if ((parsetime_error = rrd_parsetime(optarg, &start_tv))) {
                 rrd_set_error("start time: %s", parsetime_error);
                 return -1;
             }
             break;
         case 'e':
-            if ((parsetime_error = parsetime(optarg, &end_tv))) {
+            if ((parsetime_error = rrd_parsetime(optarg, &end_tv))) {
                 rrd_set_error("end time: %s", parsetime_error);
                 return -1;
             }
@@ -116,7 +115,7 @@ int rrd_xport(
         }
     }
 
-    if (proc_start_end(&start_tv, &end_tv, &start_tmp, &end_tmp) == -1) {
+    if (rrd_proc_start_end(&start_tv, &end_tv, &start_tmp, &end_tmp) == -1) {
         return -1;
     }
 
@@ -143,7 +142,7 @@ int rrd_xport(
     }
 
     if (im.gdes_c == 0) {
-        rrd_set_error("can't make an xport without contents");
+        rrd_set_error("can't make a graph without contents");
         im_free(&im);
         return (-1);
     }
@@ -172,15 +171,20 @@ int rrd_xport_fn(
 {                       /* two dimensional array containing the data */
 
     int       i = 0, j = 0;
-    unsigned long dst_row, row_cnt;
-    rrd_value_t  *dstptr;
+    unsigned long *ds_cnt;  /* number of data sources in file */
+    unsigned long col, dst_row, row_cnt;
+    rrd_value_t *srcptr, *dstptr;
 
+    unsigned long nof_xports = 0;
     unsigned long xport_counter = 0;
     int      *ref_list;
-    long     *step_list;
-    long     *step_list_ptr;    
+    rrd_value_t **srcptr_list;
     char    **legend_list;
+    int       ii = 0;
 
+    time_t    start_tmp = 0;
+    time_t    end_tmp = 0;
+    unsigned long step_tmp = 1;
 
     /* pull the data from the rrd files ... */
     if (data_fetch(im) == -1)
@@ -191,50 +195,97 @@ int rrd_xport_fn(
         return -1;
 
     /* how many xports? */
-    *col_cnt = 0;    
     for (i = 0; i < im->gdes_c; i++) {
         switch (im->gdes[i].gf) {
         case GF_XPORT:
-            (*col_cnt)++;
+            nof_xports++;
             break;
         default:
             break;
         }
     }
-    if ((*col_cnt) == 0) {
+    if (nof_xports == 0) {
         rrd_set_error("no XPORT found, nothing to do");
         return -1;
     }
 
     /* a list of referenced gdes */
-    ref_list = malloc(sizeof(int) * (*col_cnt));
+    ref_list = malloc(sizeof(int) * nof_xports);
     if (ref_list == NULL)
         return -1;
 
-    /* a list to save pointers to the column's legend entry */
-    /* this is a return value! */
-    legend_list = malloc(sizeof(char *) * (*col_cnt));
-    if (legend_list == NULL) {
+    /* a list to save pointers into each gdes data */
+    srcptr_list = malloc(sizeof(srcptr) * nof_xports);
+    if (srcptr_list == NULL) {
         free(ref_list);
         return -1;
     }
 
-    /* lets find the step size we have to use for xport */
-    step_list = malloc(sizeof(long)*((*col_cnt)+1));
-    step_list_ptr = step_list;
+    /* a list to save pointers to the column's legend entry */
+    /* this is a return value! */
+    legend_list = malloc(sizeof(char *) * nof_xports);
+    if (legend_list == NULL) {
+        free(srcptr_list);
+        free(ref_list);
+        return -1;
+    }
+
+    /* find referenced gdes and save their index and */
+    /* a pointer into their data */
+    for (i = 0; i < im->gdes_c; i++) {
+        switch (im->gdes[i].gf) {
+        case GF_XPORT:
+            ii = im->gdes[i].vidx;
+            if (xport_counter > nof_xports) {
+                rrd_set_error("too many xports: should not happen. Hmmm");
+                free(srcptr_list);
+                free(ref_list);
+                free(legend_list);
+                return -1;
+            }
+            srcptr_list[xport_counter] = im->gdes[ii].data;
+            ref_list[xport_counter++] = i;
+            break;
+        default:
+            break;
+        }
+    }
+
+    start_tmp = im->gdes[0].start;
+    end_tmp = im->gdes[0].end;
+    step_tmp = im->gdes[0].step;
+
+    /* fill some return values */
+    *col_cnt = nof_xports;
+    *start = start_tmp;
+    *end = end_tmp;
+    *step = step_tmp;
+
+    row_cnt = ((*end) - (*start)) / (*step);
+
+    /* room for rearranged data */
+    /* this is a return value! */
+    if (((*data) =
+         malloc((*col_cnt) * row_cnt * sizeof(rrd_value_t))) == NULL) {
+        free(srcptr_list);
+        free(ref_list);
+        free(legend_list);
+        rrd_set_error("malloc xport data area");
+        return (-1);
+    }
+    dstptr = (*data);
+
     j = 0;
     for (i = 0; i < im->gdes_c; i++) {
         switch (im->gdes[i].gf) {
         case GF_XPORT:
-            ref_list[xport_counter++] = i;
-            *step_list_ptr = im->gdes[im->gdes[i].vidx].step;
-            printf("%s:%lu\n",im->gdes[i].legend,*step_list_ptr);
-            *step_list_ptr++;
             /* reserve room for one legend entry */
             /* is FMT_LEG_LEN + 5 the correct size? */
             if ((legend_list[j] =
-                malloc(sizeof(char) * (FMT_LEG_LEN + 5))) == NULL) {
+                 malloc(sizeof(char) * (FMT_LEG_LEN + 5))) == NULL) {
+                free(srcptr_list);
                 free(ref_list);
+                free(*data);
                 *data = NULL;
                 while (--j > -1)
                     free(legend_list[j]);
@@ -248,49 +299,41 @@ int rrd_xport_fn(
                 strcpy(legend_list[j++], im->gdes[i].legend);
             else
                 legend_list[j++][0] = '\0';
+
             break;
         default:
-            break;            
+            break;
         }
     }
-    *step_list_ptr=0;    
-    /* find a common step */
-    *step = lcd(step_list);
-    printf("step: %lu\n",*step);
-    free(step_list);
-    
-    *start =  im->start - im->start % (*step);
-    *end = im->end - im->end % (*step);
-    
-
-    /* room for rearranged data */
-    /* this is a return value! */
-    row_cnt = ((*end) - (*start)) / (*step);
-    if (((*data) =
-         malloc((*col_cnt) * row_cnt * sizeof(rrd_value_t))) == NULL) {
-        free(ref_list);
-        free(legend_list);
-        rrd_set_error("malloc xport data area");
-        return (-1);
-    }
-    dstptr = (*data);
 
     /* fill data structure */
     for (dst_row = 0; (int) dst_row < (int) row_cnt; dst_row++) {
-        for (i = 0; i < (int) (*col_cnt); i++) {
-            long vidx = im->gdes[ref_list[i]].vidx;
-            time_t now = *start + dst_row * *step;
-            (*dstptr++) = im->gdes[vidx].data[(unsigned long)
-                                              floor((double)
-                                                    (now - im->gdes[vidx].start)
-                                                    /im->gdes[vidx].step)
-                                              * im->gdes[vidx].ds_cnt +
-                                              im->gdes[vidx].ds];
+        for (i = 0; i < (int) nof_xports; i++) {
+            j = ref_list[i];
+            ii = im->gdes[j].vidx;
+            ds_cnt = &im->gdes[ii].ds_cnt;
 
+            srcptr = srcptr_list[i];
+            for (col = 0; col < (*ds_cnt); col++) {
+                rrd_value_t newval = DNAN;
+
+                newval = srcptr[col];
+
+                if (im->gdes[ii].ds_namv && im->gdes[ii].ds_nam) {
+                    if (strcmp(im->gdes[ii].ds_namv[col], im->gdes[ii].ds_nam)
+                        == 0)
+                        (*dstptr++) = newval;
+                } else {
+                    (*dstptr++) = newval;
+                }
+
+            }
+            srcptr_list[i] += (*ds_cnt);
         }
     }
 
     *legend_v = legend_list;
+    free(srcptr_list);
     free(ref_list);
     return 0;
 
