@@ -37,24 +37,20 @@
 #define finite _finite
 #define snprintf _snprintf
 #define vsnprintf _vsnprintf
-#define strftime strftime_ 
+#define strftime strftime_
 
 #define NO_NULL_REALLOC 1
 #if NO_NULL_REALLOC
 # define rrd_realloc(a,b) ( (a) == NULL ? malloc( (b) ) : realloc( (a) , (b) ))
 #else
 # define rrd_realloc(a,b) realloc((a), (b))
-#endif      
+#endif
 
 /* Vertical label angle: 90.0 (default) or 270.0 */
 #define RRDGRAPH_YLEGEND_ANGLE 90.0
 
-#define RRD_DEFAULT_FONT "arial.ttf"
-/* #define RRD_DEFAULT_FONT "DejaVuSansMono-Roman.ttf" */
-
-/* #define WITH_PIECHART 1 */
+#define RRD_DEFAULT_FONT "Courier"
 
 /* #define DEBUG 1 */
 
-#endif /* CONFIG_H */
-
+#endif                          /* CONFIG_H */
